Crate zerobox_utils_absolute_path

Crate zerobox_utils_absolute_path 

Modules

test_support
Helpers for constructing absolute paths in tests.

Structs

AbsolutePathBuf
A path that is guaranteed to be absolute and normalized (though it is not guaranteed to be canonicalized or exist on the filesystem).
AbsolutePathBufGuard
Ensure this guard is held while deserializing AbsolutePathBuf values to provide a base path for resolving relative paths. Because this relies on thread-local storage, the deserialization must be single-threaded and occur on the same thread that created the guard.

Functions

canonicalize_existing_preserving_symlinks
Canonicalize an existing path while preserving the logical absolute path whenever canonicalization would rewrite it through a nested symlink.
canonicalize_preserving_symlinks
Canonicalize a path when possible, but preserve the logical absolute path whenever canonicalization would rewrite it through a nested symlink.